@@ -4,7 +4,7 @@ compute_consensus_peaks_consensusseeker <- function(grlist,
     bsgen <- check_genome_build(genome_build = genome_build,
                                 type = "bsgen")
     chrInfo <- GenomicRanges::seqinfo(bsgen)[
-        GenomeInfoDb::seqlevelsInUse(grlist)
+        Seqinfo::seqlevelsInUse(grlist)
     ]  
     consensus_peaks <- consensusSeekeR::findConsensusPeakRegions( 
         peaks = unlist(grlist),
@@ -12,4 +12,4 @@ compute_consensus_peaks_consensusseeker <- function(grlist,
         ...
     )$consensusRanges
     return(consensus_peaks)
-}
\ No newline at end of file
+}
